Crate musli_wire
source · [−]Expand description
Fully upgrade stable format for Müsli suitable for network communication.
Wire encoding is fully upgrade stable:
- ✔ Can tolerate missing fields if they are annotated with
#[musli(default)]. - ✔ Can skip over unknown fields.
This means that it’s suitable as a wire format, since the data model can evolve independently among clients. Once some clients are upgraded they will start sending unknown fields which non-upgraded clients will be forced to skip over for the duration of the upgrade.
use musli::{Encode, Decode};
#[derive(Debug, PartialEq, Encode, Decode)]
struct Version1 {
name: String,
}
#[derive(Debug, PartialEq, Encode, Decode)]
struct Version2 {
name: String,
#[musli(default)]
age: Option<u32>,
}
let version2 = musli_wire::to_vec(&Version2 {
name: String::from("Aristotle"),
age: Some(62),
})?;
let version1: Version1 = musli_wire::decode(&version2[..])?;
assert_eq!(version1, Version1 {
name: String::from("Aristotle"),
});Configuring
To configure the behavior of the wire format you can use the WireEncoding type:
use musli_wire::WireEncoding;
use musli_wire::{Fixed, Variable};
use musli::{Encode, Decode};
const CONFIG: WireEncoding<Fixed, Variable, 128> = WireEncoding::new()
.with_fixed_integers()
.with_max_pack::<128>();
#[derive(Debug, PartialEq, Encode, Decode)]
struct Struct<'a> {
name: &'a str,
age: u32,
}
let mut out = Vec::new();
let expected = Struct {
name: "Aristotle",
age: 61,
};
CONFIG.encode(&mut out, &expected)?;
let actual = CONFIG.decode(&out[..])?;
assert_eq!(expected, actual);Implementation details
Each field is prefix typed with a single byte tag that allows a receiver to figure out exactly how much should be skipped over.
The types available are defined in the [types] module.
Re-exports
pub use self::encoding::decode;pub use self::encoding::encode;pub use self::encoding::from_slice;pub use self::encoding::to_fixed_bytes;pub use self::encoding::WireEncoding;pub use self::encoding::to_vec;pub use self::encoding::to_writer;Modules
Module that defines WireEncoding whith allows for customization of the encoding format, and the DEFAULT encoding configuration.
Type flags available for musli-wire.
Structs
A fixed-length integer encoding which encodes something to a little-endian encoding.
A fixed-size bytes storage which keeps track of how much has been initialized.
A fixed-length encoding which encodes numbers to the width of L and the
endianness of B.
Enums
Type that indicates that the given numerical type should use variable-length encoding.