Module that defines WireEncoding whith allows for customization of the encoding format, and the DEFAULT encoding configuration.

Structs

Setting up encoding with parameters.

Constants

The default configuration.

Functions

Decode the given type T from the given Reader using the DEFAULT configuration.

Encode the given value to the given Writer using the DEFAULT configuration.

Decode the given type T from the given slice using the DEFAULT configuration.

Encode the given value to a fixed-size bytes using the DEFAULT configuration.

Encode the given value to a Vec using the DEFAULT configuration.

Encode the given value to the given Write using the DEFAULT configuration.