Function musli_wire::encoding::from_slice
source · [−]Expand description
Decode the given type T from the given slice using the DEFAULT
configuration.
Decode the given type T from the given slice using the DEFAULT
configuration.