#[repr(transparent)]
pub struct Tag { /* private fields */ }
A type tag.

The Kind of the element is indicates by its 2 MSBs, and remaining 6 bits is the data field. The exact use of the data field depends on the Kind in question. It is primarily used to smuggle extra data for the kind in question.

Implementations

Construct a new tag through an unchecked constructor.

data must not be equal to or larger than [DATA_MASK], or else it could corrupt the payload.

Construct a new empty tag of the given Kind.

Construct from a byte.

Coerce type flag into a byte.

Access the kind of the tag.

Perform checked access over the internal data. Returns None if data is empty.

Attempt to construct a type tag with the given length embedded.

Returns a tuple where the boolean indicates if the value was embedded or not.

Attempt to construct a type tag with the given length embedded.

Returns a tuple where the boolean indicates if the value was embedded or not.